package MT::Plugin::SiteMap;

our $VERSION = '0.1';

@MT::Plugin::SiteMap::ISA = qw( MT::Plugin );

my $plugin = new MT::Plugin::SiteMap ( {
    description => '<MT_TRANS phrase=\'_PLUGIN_DESCRIPTION\'>',
    name => 'SiteMap',
    id   => 'SiteMap',
    key  => 'sitemap',
    author_name => 'Alfasado,Inc.',
    author_link => 'http://alfasado.net/',
    version => $VERSION,
    l10n_class => 'SiteMap::L10N',
} );

MT->add_plugin( $plugin );

sub init_registry {
    my $plugin = shift;
    $plugin->registry( {
        applications => {
            cms => {
                methods => {
                    sitemap =>
                        'MT::Plugin::SiteMap::_sitemap',
                },
                menus => {
                    'powercms:sitemap' => {
                        label => 'View Sitemap',
                        view  => 'blog',
                        order => 99999,
                        mode  => 'sitemap',
                        condition  => \&_menu_permission,
                    },
                },
            },
        },
   } );
}

sub _menu_permission {
    my $app = MT->instance;
    my $user  = $app->user;
    my $admin = $user->is_superuser;
    if (! $admin ) {
        return 0;
    }
    return 1;
}

sub _sitemap {
    my $app = shift;
    my $user  = $app->user;
    my $admin = $user->is_superuser;
    if (! $admin ) {
        return $app->trans_error( 'Permission denied.' );
    }
    $app->{ plugin_template_path } = File::Spec->catdir( $plugin->path,'tmpl' );
    my $type = $app->param( '_type' );
    my %param;
    my $blog = $app->blog;
    unless ( $app->param( 'blog_id' ) ) {
        my $blog_count = MT::Blog->count( undef );
        if ( $blog_count == 1 ) {
            $blog = MT::Blog->load( undef );
            return $app->redirect( $app->uri( mode => 'sitemap',
                                              args => { 'blog_id' => $blog->id, } ) );
        }
    }
    my $blog_id;
    if ( $blog ) {
        $blog_id = $blog->id;
        my $columns = $blog->column_names;
        for my $column ( @$columns ) {
            $param{ $column } = $blog->$column;
        }
        $param{ blog_id } = $blog->id;
        $param{ class } = $app->param( 'class' );
    }
    my $tmpl = 'sitemap.tmpl';
    my $plugin = MT->component( 'BlogTree' );
    my $entries_lastn_blog = $plugin->get_config_value( 'entries_lastn', 'blog:'. $blog_id ) if $blog_id;
    my $max_depth_blog = $plugin->get_config_value( 'max_depth', 'blog:'. $blog_id ) if $blog_id;
    my $max_display_blog = $plugin->get_config_value( 'max_display', 'blog:'. $blog_id ) if $blog_id;
    my $blog_name_trim_blog = $plugin->get_config_value( 'blog_name_trim', 'blog:'. $blog_id ) if $blog_id;
    my $entry_title_trim_blog = $plugin->get_config_value( 'entry_title_trim', 'blog:'. $blog_id ) if $blog_id;
    $plugin->set_config_value( 'entries_lastn', '9999', 'blog:'. $blog_id ) if $blog_id;
    $plugin->set_config_value( 'max_depth', '9999', 'blog:'. $blog_id ) if $blog_id;
    $plugin->set_config_value( 'max_display', '9999', 'blog:'. $blog_id ) if $blog_id;
    $plugin->set_config_value( 'blog_name_trim', '9999', 'blog:'. $blog_id ) if $blog_id;
    $plugin->set_config_value( 'entry_title_trim', '9999', 'blog:'. $blog_id ) if $blog_id;
    my $src = $app->build_page( $tmpl, \%param );
    $plugin->set_config_value( 'entries_lastn', $entries_lastn_blog, 'blog:'. $blog_id ) if $blog_id;
    $plugin->set_config_value( 'max_depth', $max_depth_blog, 'blog:'. $blog_id ) if $blog_id;
    $plugin->set_config_value( 'max_display', $max_display_blog, 'blog:'. $blog_id ) if $blog_id;
    $plugin->set_config_value( 'blog_name_trim', $blog_name_trim_blog, 'blog:'. $blog_id ) if $blog_id;
    $plugin->set_config_value( 'entry_title_trim', $entry_title_trim_blog, 'blog:'. $blog_id ) if $blog_id;
    return $src;
}

1;